package com.dsk.web.controller.customer;

import com.dsk.common.annotation.RepeatSubmit;
import com.dsk.common.core.controller.BaseController;
import com.dsk.common.core.domain.AjaxResult;
import com.dsk.common.core.page.TableDataInfo;
import com.dsk.system.domain.customer.Customer;
import com.dsk.system.domain.customer.dto.CustomerBusinessSearchDto;
import com.dsk.system.domain.customer.dto.CustomerSearchDto;
import com.dsk.system.service.ICustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

/**
 * 客户相关
 *
 * @author lcl
 * @create 2023/5/16
 */
@RestController
@RequestMapping("/customer")
public class CustomerController extends BaseController {

    @Autowired
    private ICustomerService baseService;

    /**
     * 查询客户列表
     */
    @PreAuthorize("@ss.hasPermi('customer:list')")
    @GetMapping("/list")
    public TableDataInfo selectPageList(CustomerSearchDto dto){
        startPage();
        return getDataTable(baseService.selectList(dto));
    }

    /**
     * 客户详情
     */
    @PreAuthorize("@ss.hasPermi('customer:info')")
    @GetMapping("/{customerId}")
    public AjaxResult info(@PathVariable("customerId") String customerId){
        return AjaxResult.success(baseService.info(customerId));
    }

    /**
     * 添加客户
     */
    @PreAuthorize("@ss.hasPermi('customer:add')")
    @PostMapping()
    @RepeatSubmit
    public AjaxResult add(@RequestBody Customer customer){
        return AjaxResult.success(baseService.add(customer));
    }

    /**
     * 编辑客户
     */
    @PreAuthorize("@ss.hasPermi('customer:edit')")
    @PutMapping()
    @RepeatSubmit
    public AjaxResult edit(@RequestBody Customer customer){
        return AjaxResult.success(baseService.edit(customer));
    }

    /**
     * 获取个人客户列表
     */
    @GetMapping("/user/list")
    public AjaxResult userList(){
        return AjaxResult.success(baseService.selectUserList());
    }

    /**
     * 获取客户项目（合作情况）列表
     */
//    @PreAuthorize("@ss.hasPermi('customer:business:list')")
    @GetMapping("/business/list")
    public TableDataInfo businessList(CustomerBusinessSearchDto dto){
        startPage();
        return getDataTable(baseService.selectBusinessList(dto));
    }

}
