package com.dsk.system.service;

import com.dsk.common.core.domain.AjaxResult;
import com.dsk.common.core.domain.entity.BusinessInfo;
import com.dsk.system.domain.BusinessAddDto;
import com.dsk.system.domain.BusinessListDto;
import com.dsk.system.domain.customer.dto.CustomerBusinessSearchDto;
import com.dsk.system.domain.customer.vo.CustomerBusinessListVo;
import com.dsk.system.domain.vo.BusinessBrowseVo;
import com.dsk.system.domain.vo.BusinessListVo;

import java.util.List;

/**
 * 项目详情Service接口
 *
 * @author ruoyi
 * @date 2023-05-17
 */
public interface IBusinessInfoService
{
    /**
     * 查询项目详情
     *
     * @param id 项目详情主键
     * @return 项目详情
     */
    public BusinessInfo selectBusinessInfoById(Integer id);

    /**
     * 查询项目建设内容
     *
     * @param id 项目详情主键
     * @return
     */
    BusinessInfo getConstruction(Integer id);

    /**
     * 查询项目详情列表
     * 
     * @param dto 项目详情
     * @return 项目详情集合
     */
    public List<BusinessListVo> selectBusinessInfoList(BusinessListDto dto);

    /**
     * 查询项目速览
     * @param businessId
     * @return
     */
    BusinessBrowseVo browse(Integer businessId);

    /**
     * 查询所有项目名称(支持模糊查询)
     * @return
     */
    List<String> selectProjectName(BusinessListDto dto);

    /**
     * 新增项目详情
     * 
     * @param dto 项目详情
     * @return 结果
     */
    public AjaxResult insertBusinessInfo(BusinessAddDto dto);

    /**
     * 修改项目详情
     * 
     * @param businessInfo 项目详情
     * @return 结果
     */
    public int updateBusinessInfo(BusinessInfo businessInfo);

    /**
     * 批量删除项目详情
     * 
     * @param ids 需要删除的项目详情主键集合
     * @return 结果
     */
    public int deleteBusinessInfoByIds(Long[] ids);

    /**
     * 删除项目详情信息
     * 
     * @param id 项目详情主键
     * @return 结果
     */
    public int deleteBusinessInfoById(Long id);

    int selectCountByStatusAndCustomerId(Integer status,String customerId);

    List<CustomerBusinessListVo> selectCustomerBusinessList(CustomerBusinessSearchDto dto);

}
